@@ -5,8 +5,10 @@ from .base import base
 
 
 class display(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     
     # 指导任务默认列表
