@@ -4,8 +4,9 @@ from loguru import logger
 
 
 class collocation(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def  __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def list(self, page=1, rows=10):
         api_name = "goods/collocation/list"
