@@ -11,8 +11,11 @@ from cjdg_api.base import base, request_accesstoken
 
 
 class cjdgGoods(base):
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
+
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
+
 
     def list(self, accounts, code=None, name=None, barCode=None):
         api_name = "open/fab/goods/list"
