@@ -27,5 +27,5 @@ class Growth_Map(baseApixxYent):
     # 新增成长地图
 
     def growth_map_add(self, data):
-        api_name = f"https://it.xxynet.com/learn_path/api/learnPathGroup/save?"
+        api_name = f"learn_path/api/learnPathGroup/save?"
         return self.request(api_name, json=data)
