@@ -6,8 +6,8 @@ from qiniu import put_file
 
 class cjdgQiniu(base):
 
-    def __init__(self, token, app_secret):
-        super().__init__(token, app_secret)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
         qn_token = self.get_token()
         self.domain = qn_token.get("domain")
         if self.domain:
