@@ -10,8 +10,8 @@ from .base import base
 
 class cjdgUser(base):
 
-    def __init__(self, token, app_secret):
-        super().__init__(token, app_secret)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def create(self, data):
         api_name = "user/create"
